@@ -351,7 +351,7 @@ from ae.core import DEBUG_LEVELS
 from ae.console import ConsoleApp                                                       # type: ignore
 
 
-__version__ = '0.1.52'
+__version__ = '0.1.53'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -515,20 +515,30 @@ def id_of_flow(action: str, obj: str = "", key: str = "") -> str:
     return cid
 
 
-def register_package_images():              # pragma: no cover
-    """ call from module scope of the package for to register/add image/img resources path. """
+def register_package_images(*skip_modules: str):              # pragma: no cover
+    """ call from module scope of the package for to register/add image/img resources path.
+
+    :param skip_modules:        list of packages/modules/portions to skip (pass at least `'ae.inspector'` for to
+                                disable the default skip modules, e.g. if you want to register resources provided by a
+                                ae namespace portion that gets by default skipped).
+        """
     global FOUND_IMAGES
 
-    package_path = os.path.abspath(os.path.dirname(stack_var('__file__')))
+    package_path = os.path.abspath(os.path.dirname(stack_var('__file__', *skip_modules)))
     search_path = os.path.join(package_path, 'img/**')
     FOUND_IMAGES.add_paths(search_path)
 
 
-def register_package_sounds():              # pragma: no cover
-    """ call from module scope of the package for to register/add sound file resources. """
+def register_package_sounds(*skip_modules: str):              # pragma: no cover
+    """ call from module scope of the package for to register/add sound file resources.
+
+    :param skip_modules:        list of packages/modules/portions to skip (pass at least `'ae.inspector'` for to
+                                disable the default skip modules, e.g. if you want to register resources provided by a
+                                ae namespace portion that gets by default skipped).
+    """
     global FOUND_SOUNDS
 
-    package_path = os.path.abspath(os.path.dirname(stack_var('__file__')))
+    package_path = os.path.abspath(os.path.dirname(stack_var('__file__', *skip_modules)))
     search_path = os.path.join(package_path, 'snd/**')
     FOUND_SOUNDS.add_paths(search_path)
 
@@ -1205,7 +1215,8 @@ class MainAppBase(ConsoleApp, ABC):
         self.call_method('on_win_pos_size')
 
 
-register_package_sounds()   # register base sound files of this portion
+register_package_images('ae.inspector')   # register base image files of this portion
+register_package_sounds('ae.inspector')   # register base sound files of this portion
 
 module_globals = globals()
 #: used. e.g. by :mod:`ae.gui_help` for execution/evaluation of dynamic code, expressions and f-strings
